@@ -1,3 +1,3 @@
 """Asynchronous Python client for IPP."""
 from .ipp import IPP, IPPConnectionError, IPPError  # noqa
-from .printer import Printer  # noqa
+from .models import Printer  # noqa
